@@ -1,6 +1,10 @@
+import requests
+from requests import RequestException
 from schematics.models import Model, ValidationError
 from schematics.types import UUIDType, URLType, StringType, DictType, IntType, FloatType, UnionType, BooleanType
 
+from basemodels.constants import SUPPORTED_CONTENT_TYPES
+
 
 class TaskDataEntry(Model):
     """
@@ -36,9 +40,25 @@ class TaskDataEntry(Model):
         return value
 
 
-def validate_taskdata_entry(value: dict):
+def validate_content_type(uri: str) -> None:
+    """ Validate uri content type """
+    try:
+        response = requests.head(uri)
+        response.raise_for_status()
+    except RequestException as e:
+        raise ValidationError(f"taskdata content type ({uri}) validation failed") from e
+
+    content_type = response.headers.get("Content-Type", "")
+    if content_type not in SUPPORTED_CONTENT_TYPES:
+        raise ValidationError(f"taskdata entry datapoint_uri has unsupported type {content_type}")
+
+
+def validate_taskdata_entry(value: dict, validate_image_content_type: bool) -> None:
     """ Validate taskdata entry """
     if not isinstance(value, dict):
         raise ValidationError("taskdata entry should be dict")
 
     TaskDataEntry(value).validate()
+
+    if validate_image_content_type:
+        validate_content_type(value['datapoint_uri'])
