@@ -1,16 +1,16 @@
 import uuid
 import requests
 from requests.exceptions import RequestException
-from typing import Dict, Callable, Any, Union
+from typing import Callable, Any
 from schematics.models import Model, ValidationError
 from schematics.exceptions import BaseError
-from schematics.types import StringType, DecimalType, BooleanType, IntType, DictType, ListType, URLType, FloatType, \
-    UUIDType, ModelType, BooleanType, UnionType, NumberType, BaseType
+from schematics.types import StringType, DecimalType, IntType, DictType, ListType, URLType, FloatType, \
+    UUIDType, ModelType, BooleanType, UnionType
 
-from .data.groundtruth import validate_groundtruth_entry
-from .data.taskdata import validate_taskdata_entry
-from .data.preprocess import Preprocess
-from .restricted_audience import RestrictedAudience
+from basemodels.manifest.data.groundtruth import validate_groundtruth_entry
+from basemodels.manifest.data.taskdata import validate_taskdata_entry
+from basemodels.manifest.restricted_audience import RestrictedAudience
+from basemodels.constants import JOB_TYPES_FOR_CONTENT_TYPE_VALIDATION
 
 BASE_JOB_TYPES = [
     "image_label_binary",
@@ -275,7 +275,7 @@ class Manifest(Model):
     webhook = ModelType(Webhook)
 
 
-def traverse_json_entries(data: Any, callback: Callable) -> int:
+def traverse_json_entries(data: Any, callback: Callable, validate_image_content_type: bool) -> int:
     """
     Traverse json and execute callback for each top-level entry
 
@@ -290,12 +290,14 @@ def traverse_json_entries(data: Any, callback: Callable) -> int:
     if isinstance(data, dict):
         for k, v in data.items():
             entries_count += 1
-            callback(k, v)
+            callback(k, v, validate_image_content_type)
+            validate_image_content_type = False
 
     elif isinstance(data, list):
         for v in data:
             entries_count += 1
-            callback(None, v)
+            callback(None, v, validate_image_content_type)
+            validate_image_content_type = False
 
     return entries_count
 
@@ -304,13 +306,13 @@ def validate_manifest_uris(manifest: dict):
     """ Fetch & validate manifest's remote objects """
 
     request_type = manifest.get('request_type', '')
-
     entry_validators = {
-        "groundtruth_uri": lambda k, v: validate_groundtruth_entry(k, v, request_type),
-        "taskdata_uri": lambda _, v: validate_taskdata_entry(v)
+        "groundtruth_uri": lambda k, v, validate: validate_groundtruth_entry(k, v, request_type, validate),
+        "taskdata_uri": lambda _, v, validate: validate_taskdata_entry(v, validate)
     }
 
     for uri_key, validate_entry in entry_validators.items():
+        validate_image_content_type = request_type in JOB_TYPES_FOR_CONTENT_TYPE_VALIDATION
         uri = manifest.get(uri_key)
 
         if uri is None:
@@ -320,7 +322,7 @@ def validate_manifest_uris(manifest: dict):
             response = requests.get(uri)
             response.raise_for_status()
 
-            entries_count = traverse_json_entries(response.json(), validate_entry)
+            entries_count = traverse_json_entries(response.json(), validate_entry, validate_image_content_type)
         except (BaseError, RequestException) as e:
             raise ValidationError(f"{uri_key} validation failed: {e}") from e
 
